@@ -265,6 +265,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_codeguruprofiler
@@ -333,6 +335,17 @@ class BundlingOptions:
                 )
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(BundlingOptions.__init__)
+            check_type(argname="argument asset_hash", value=asset_hash, expected_type=type_hints["asset_hash"])
+            check_type(argname="argument asset_hash_type", value=asset_hash_type, expected_type=type_hints["asset_hash_type"])
+            check_type(argname="argument build_args", value=build_args, expected_type=type_hints["build_args"])
+            check_type(argname="argument cgo_enabled", value=cgo_enabled, expected_type=type_hints["cgo_enabled"])
+            check_type(argname="argument command_hooks", value=command_hooks, expected_type=type_hints["command_hooks"])
+            check_type(argname="argument docker_image", value=docker_image, expected_type=type_hints["docker_image"])
+            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
+            check_type(argname="argument forced_docker_bundling", value=forced_docker_bundling, expected_type=type_hints["forced_docker_bundling"])
+            check_type(argname="argument go_build_flags", value=go_build_flags, expected_type=type_hints["go_build_flags"])
         self._values: typing.Dict[str, typing.Any] = {}
         if asset_hash is not None:
             self._values["asset_hash"] = asset_hash
@@ -525,7 +538,7 @@ class GoFunction(
         id: builtins.str,
         *,
         entry: builtins.str,
-        bundling: typing.Optional[BundlingOptions] = None,
+        bundling: typing.Optional[typing.Union[BundlingOptions, typing.Dict[str, typing.Any]]] = None,
         module_dir: typing.Optional[builtins.str] = None,
         runtime: typing.Optional[aws_cdk.aws_lambda.Runtime] = None,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
@@ -533,7 +546,7 @@ class GoFunction(
         architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
         architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
         code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
-        current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
+        current_version_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.VersionOptions, typing.Dict[str, typing.Any]]] = None,
         dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
         dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
@@ -548,7 +561,7 @@ class GoFunction(
         insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
         layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
-        log_retention_retry_options: typing.Optional[aws_cdk.aws_lambda.LogRetentionRetryOptions] = None,
+        log_retention_retry_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.LogRetentionRetryOptions, typing.Dict[str, typing.Any]]] = None,
         log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
         memory_size: typing.Optional[jsii.Number] = None,
         profiling: typing.Optional[builtins.bool] = None,
@@ -560,7 +573,7 @@ class GoFunction(
         timeout: typing.Optional[aws_cdk.core.Duration] = None,
         tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
         max_event_age: typing.Optional[aws_cdk.core.Duration] = None,
         on_failure: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
         on_success: typing.Optional[aws_cdk.aws_lambda.IDestination] = None,
@@ -613,6 +626,10 @@ class GoFunction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(GoFunction.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GoFunctionProps(
             entry=entry,
             bundling=bundling,
@@ -720,7 +737,7 @@ class GoFunctionProps(aws_cdk.aws_lambda.FunctionOptions):
         architecture: typing.Optional[aws_cdk.aws_lambda.Architecture] = None,
         architectures: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.Architecture]] = None,
         code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
-        current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
+        current_version_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.VersionOptions, typing.Dict[str, typing.Any]]] = None,
         dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
         dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
@@ -735,7 +752,7 @@ class GoFunctionProps(aws_cdk.aws_lambda.FunctionOptions):
         insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
         layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
-        log_retention_retry_options: typing.Optional[aws_cdk.aws_lambda.LogRetentionRetryOptions] = None,
+        log_retention_retry_options: typing.Optional[typing.Union[aws_cdk.aws_lambda.LogRetentionRetryOptions, typing.Dict[str, typing.Any]]] = None,
         log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
         memory_size: typing.Optional[jsii.Number] = None,
         profiling: typing.Optional[builtins.bool] = None,
@@ -747,9 +764,9 @@ class GoFunctionProps(aws_cdk.aws_lambda.FunctionOptions):
         timeout: typing.Optional[aws_cdk.core.Duration] = None,
         tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
         entry: builtins.str,
-        bundling: typing.Optional[BundlingOptions] = None,
+        bundling: typing.Optional[typing.Union[BundlingOptions, typing.Dict[str, typing.Any]]] = None,
         module_dir: typing.Optional[builtins.str] = None,
         runtime: typing.Optional[aws_cdk.aws_lambda.Runtime] = None,
     ) -> None:
@@ -817,6 +834,49 @@ class GoFunctionProps(aws_cdk.aws_lambda.FunctionOptions):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
         if isinstance(bundling, dict):
             bundling = BundlingOptions(**bundling)
+        if __debug__:
+            type_hints = typing.get_type_hints(GoFunctionProps.__init__)
+            check_type(argname="argument max_event_age", value=max_event_age, expected_type=type_hints["max_event_age"])
+            check_type(argname="argument on_failure", value=on_failure, expected_type=type_hints["on_failure"])
+            check_type(argname="argument on_success", value=on_success, expected_type=type_hints["on_success"])
+            check_type(argname="argument retry_attempts", value=retry_attempts, expected_type=type_hints["retry_attempts"])
+            check_type(argname="argument allow_all_outbound", value=allow_all_outbound, expected_type=type_hints["allow_all_outbound"])
+            check_type(argname="argument allow_public_subnet", value=allow_public_subnet, expected_type=type_hints["allow_public_subnet"])
+            check_type(argname="argument architecture", value=architecture, expected_type=type_hints["architecture"])
+            check_type(argname="argument architectures", value=architectures, expected_type=type_hints["architectures"])
+            check_type(argname="argument code_signing_config", value=code_signing_config, expected_type=type_hints["code_signing_config"])
+            check_type(argname="argument current_version_options", value=current_version_options, expected_type=type_hints["current_version_options"])
+            check_type(argname="argument dead_letter_queue", value=dead_letter_queue, expected_type=type_hints["dead_letter_queue"])
+            check_type(argname="argument dead_letter_queue_enabled", value=dead_letter_queue_enabled, expected_type=type_hints["dead_letter_queue_enabled"])
+            check_type(argname="argument dead_letter_topic", value=dead_letter_topic, expected_type=type_hints["dead_letter_topic"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
+            check_type(argname="argument environment_encryption", value=environment_encryption, expected_type=type_hints["environment_encryption"])
+            check_type(argname="argument ephemeral_storage_size", value=ephemeral_storage_size, expected_type=type_hints["ephemeral_storage_size"])
+            check_type(argname="argument events", value=events, expected_type=type_hints["events"])
+            check_type(argname="argument filesystem", value=filesystem, expected_type=type_hints["filesystem"])
+            check_type(argname="argument function_name", value=function_name, expected_type=type_hints["function_name"])
+            check_type(argname="argument initial_policy", value=initial_policy, expected_type=type_hints["initial_policy"])
+            check_type(argname="argument insights_version", value=insights_version, expected_type=type_hints["insights_version"])
+            check_type(argname="argument layers", value=layers, expected_type=type_hints["layers"])
+            check_type(argname="argument log_retention", value=log_retention, expected_type=type_hints["log_retention"])
+            check_type(argname="argument log_retention_retry_options", value=log_retention_retry_options, expected_type=type_hints["log_retention_retry_options"])
+            check_type(argname="argument log_retention_role", value=log_retention_role, expected_type=type_hints["log_retention_role"])
+            check_type(argname="argument memory_size", value=memory_size, expected_type=type_hints["memory_size"])
+            check_type(argname="argument profiling", value=profiling, expected_type=type_hints["profiling"])
+            check_type(argname="argument profiling_group", value=profiling_group, expected_type=type_hints["profiling_group"])
+            check_type(argname="argument reserved_concurrent_executions", value=reserved_concurrent_executions, expected_type=type_hints["reserved_concurrent_executions"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument security_groups", value=security_groups, expected_type=type_hints["security_groups"])
+            check_type(argname="argument timeout", value=timeout, expected_type=type_hints["timeout"])
+            check_type(argname="argument tracing", value=tracing, expected_type=type_hints["tracing"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
+            check_type(argname="argument entry", value=entry, expected_type=type_hints["entry"])
+            check_type(argname="argument bundling", value=bundling, expected_type=type_hints["bundling"])
+            check_type(argname="argument module_dir", value=module_dir, expected_type=type_hints["module_dir"])
+            check_type(argname="argument runtime", value=runtime, expected_type=type_hints["runtime"])
         self._values: typing.Dict[str, typing.Any] = {
             "entry": entry,
         }
@@ -1530,6 +1590,10 @@ class _ICommandHooksProxy:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ICommandHooks.after_bundling)
+            check_type(argname="argument input_dir", value=input_dir, expected_type=type_hints["input_dir"])
+            check_type(argname="argument output_dir", value=output_dir, expected_type=type_hints["output_dir"])
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "afterBundling", [input_dir, output_dir]))
 
     @jsii.member(jsii_name="beforeBundling")
@@ -1547,6 +1611,10 @@ class _ICommandHooksProxy:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ICommandHooks.before_bundling)
+            check_type(argname="argument input_dir", value=input_dir, expected_type=type_hints["input_dir"])
+            check_type(argname="argument output_dir", value=output_dir, expected_type=type_hints["output_dir"])
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "beforeBundling", [input_dir, output_dir]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
